package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.DksqLcjl;

/**
 * 贷款申请_流程记录Service接口
 * 
 * @author boman
 * @date 2023-06-15
 */
public interface IDksqLcjlService 
{
    /**
     * 查询贷款申请_流程记录
     * 
     * @param id 贷款申请_流程记录主键
     * @return 贷款申请_流程记录
     */
    public DksqLcjl selectDksqLcjlById(Long id);

    /**
     * 查询贷款申请_流程记录列表
     * 
     * @param dksqLcjl 贷款申请_流程记录
     * @return 贷款申请_流程记录集合
     */
    public List<DksqLcjl> selectDksqLcjlList(DksqLcjl dksqLcjl);

    /**
     * 新增贷款申请_流程记录
     * 
     * @param dksqLcjl 贷款申请_流程记录
     * @return 结果
     */
    public int insertDksqLcjl(DksqLcjl dksqLcjl);

    /**
     * 修改贷款申请_流程记录
     * 
     * @param dksqLcjl 贷款申请_流程记录
     * @return 结果
     */
    public int updateDksqLcjl(DksqLcjl dksqLcjl);

    /**
     * 批量删除贷款申请_流程记录
     * 
     * @param ids 需要删除的贷款申请_流程记录主键集合
     * @return 结果
     */
    public int deleteDksqLcjlByIds(Long[] ids);

    /**
     * 删除贷款申请_流程记录信息
     * 
     * @param id 贷款申请_流程记录主键
     * @return 结果
     */
    public int deleteDksqLcjlById(Long id);
}
