package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.DksqLcjl;
import com.ruoyi.system.service.IDksqLcjlService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 贷款申请_流程记录Controller
 * 
 * @author boman
 * @date 2023-06-15
 */
@RestController
@RequestMapping("/system/lcjl")
public class DksqLcjlController extends BaseController
{
    @Autowired
    private IDksqLcjlService dksqLcjlService;

    /**
     * 查询贷款申请_流程记录列表
     */
    @PreAuthorize("@ss.hasPermi('system:lcjl:list')")
    @GetMapping("/list")
    public TableDataInfo list(DksqLcjl dksqLcjl)
    {
        startPage();
        List<DksqLcjl> list = dksqLcjlService.selectDksqLcjlList(dksqLcjl);
        return getDataTable(list);
    }

    /**
     * 导出贷款申请_流程记录列表
     */
    @PreAuthorize("@ss.hasPermi('system:lcjl:export')")
    @Log(title = "贷款申请_流程记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DksqLcjl dksqLcjl)
    {
        List<DksqLcjl> list = dksqLcjlService.selectDksqLcjlList(dksqLcjl);
        ExcelUtil<DksqLcjl> util = new ExcelUtil<DksqLcjl>(DksqLcjl.class);
        util.exportExcel(response, list, "贷款申请_流程记录数据");
    }

    /**
     * 获取贷款申请_流程记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:lcjl:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(dksqLcjlService.selectDksqLcjlById(id));
    }

    /**
     * 新增贷款申请_流程记录
     */
    @PreAuthorize("@ss.hasPermi('system:lcjl:add')")
    @Log(title = "贷款申请_流程记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DksqLcjl dksqLcjl)
    {
        return toAjax(dksqLcjlService.insertDksqLcjl(dksqLcjl));
    }

    /**
     * 修改贷款申请_流程记录
     */
    @PreAuthorize("@ss.hasPermi('system:lcjl:edit')")
    @Log(title = "贷款申请_流程记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DksqLcjl dksqLcjl)
    {
        return toAjax(dksqLcjlService.updateDksqLcjl(dksqLcjl));
    }

    /**
     * 删除贷款申请_流程记录
     */
    @PreAuthorize("@ss.hasPermi('system:lcjl:remove')")
    @Log(title = "贷款申请_流程记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(dksqLcjlService.deleteDksqLcjlByIds(ids));
    }
}
